[gimp] app: enable XCF version 12 which finally saves big-endian tile data only



commit ebbcaddae738e10cf8b3972801d235124572b05f
Author: Michael Natterer <mitch gimp org>
Date:   Sun Oct 1 17:28:20 2017 +0200

    app: enable XCF version 12 which finally saves big-endian tile data only

 app/core/gimpimage.c |    7 ++++++-
 1 files changed, 6 insertions(+), 1 deletions(-)
---
diff --git a/app/core/gimpimage.c b/app/core/gimpimage.c
index 083c7c1..3a00aea 100644
--- a/app/core/gimpimage.c
+++ b/app/core/gimpimage.c
@@ -2456,10 +2456,14 @@ gimp_image_get_xcf_version (GimpImage    *image,
    * saved through parasites, which is compatible with older versions.
    */
 
   /* need version 7 for high bit depth images */
   if (gimp_image_get_precision (image) != GIMP_PRECISION_U8_GAMMA)
     version = MAX (7, version);
 
+  /* need version 12 for > 8-bit images for proper endian swapping */
+  if (gimp_image_get_precision (image) > GIMP_PRECISION_U8_GAMMA)
+    version = MAX (12, version);
+
   /* need version 8 for zlib compression */
   if (zlib_compression)
     version = MAX (8, version);
@@ -2499,6 +2503,7 @@ gimp_image_get_xcf_version (GimpImage    *image,
     case 9:
     case 10:
     case 11:
+    case 12:
       if (gimp_version)   *gimp_version   = 210;
       if (version_string) *version_string = "GIMP 2.10";
       break;
@@ -2456,10 +2456,14 @@ gimp_image_get_xcf_version (GimpImage    *image,
    */
 
-  /* need version 7 for high bit depth images */
+  /* need version 7 for != 8-bit gamma images */
   if (gimp_image_get_precision (image) != GIMP_PRECISION_U8_GAMMA)
     version = MAX (7, version);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]